#include "rwmake.ch"
#include "PROTHEUS.CH"                
#include "TOPCONN.CH"
#include "AP5MAIL.CH"
#include "TBICONN.CH"
#include "Fileio.ch"

/*/
+--+
| Funcao    | RMWF27                                                        |
+--+--+--+--+
| Autor     | Elivelton Cristian                        | Data | 12/05/2015 |
+--+--+--+--+
| Descricao | Programa para gerar arquivos de vendas e enviar para	        | 
|           | email dos clientes        			                        |
+--+--+
| Uso       | Especifico RM                                                 |
+--+
+--+
| Atualizaes Sofridas Desde a Construo Inicial                          |
+-++
| Programador       | Data    |    Motivo da Alteracao                      |      
+-|---+---+
|                   |         |                                             |
+------+---+--+ 
/*/


User Function  RMWF27()

local result:= .t.           
local cArquivo:= ""
local i,j := 0
local cGrupo4:= "0105"
local aRelatorio := {{"ABC_GERAL",{"GERAL"}}}

WFPREPENV("01","01","RMWF27")

//excluir arquivos antigo                                    
limparArqs()

for i:=1 to len(aRelatorios)
    cNomeRel:= aRelatorios[i][1]+"_"+DtoS(DATE())                              
    cGrupo:=aRelatorios[i][2][1]
	if(Substr(cNomeRel,1,3) == "ABC")
	     //chama relatorio curva ABC
	    relCurvABC("\workflow\esprm\"+cNomeRel+".txt",IF(cGrupo=="GERAL","",cGrupo))
	else
		 //chama relatorio de positivao
		relPositiv("\workflow\esprm\"+cNomeRel+".txt",IF(cGrupo=="GERAL",{"","ZZZZ"},aRelatorios[i][2]))   // Inativo
	endif
		//enviar arquivo gerado por email
		envEmail("elivelton@rmbr.com.br",cNomeRel,"\workflow\esprm\"+cNomeRel+".txt")

next


return result

/*
//-----------------------------------------------------------//
// Autor:Emerson B. Nascimento |Data: 15/10/2012             //
//-----------------------------------------------------------//
//Descricao: Funo que anexa um arquivo texto passado por   //
//          |parametro e enviar para email.                  //
//-----------------------------------------------------------//
//Nome:      envEmail(cPara,cParams)                         //
//-----------------------------------------------------------//
//Parametros: params->caminho do arquvio p/ anexar           //
//          | cPara->destinatrio para envio do email        //
			| cAssunto->Assunto do email(Nome do relatorio)  //
//-----------------------------------------------------------//
*/                                                             

static function envEmail(cPara,cAssunto,cParams)
Private lEnvia := .F.
Private cPass     := 'djdle*7390'
Private cAccount  := 'sistema@rmbr.com.br'
Private cServer   := 'smtp.rmbr.com.br:587'
Private cRemetent := 'sistema@rmbr.com.br'
Private aLista    := {}     
Private cMsg      := cAssunto+" - at "+DtoS(DATE())

	Aadd( aLista, cPara )     
	aFiles := { cParams }
		if !empty(cPara)
			CONNECT SMTP SERVER cServer ACCOUNT cAccount PASSWORD cPass
			MAILAUTH(cAccount,cPass)	
		    lEnviado := .f.
			SEND MAIL FROM cRemetent;
			TO aLista[1];
			SUBJECT cAssunto ;
			BODY cMsg ;
			ATTACHMENT aFiles[1];
			RESULT lEnviado
			DISCONNECT SMTP SERVER
		endif   

conout(cAssunto)
return 

/*
//-----------------------------------------------------------//
// Autor:Emerson B. Nascimento |Data: 15/10/2012             //
//-----------------------------------------------------------//
//Descricao: Funo Deleta arquivos antigos que esta na pasta//
//-----------------------------------------------------------//
//Nome:      limparArqs()   		                         //
//-----------------------------------------------------------//
*/                                                             

static function limparArqs()
local i := 0
local cDiretorio := "\workflow\esprm\"
local aDirectory := DIRECTORY(cDiretorio+"*.txt","D")
local nTamArray:= len(aDirectory)

for i:=1 to len(aDirectory)
	IF(FERASE(cDiretorio+aDirectory[i][1])) == -1
		conout('Falha na deleo do Arquivo ( FError'+str(ferror(),4)+ ')')
	ELSE
		conout('Arquivo deletado com sucesso.')
	ENDIF	
next

return 

/*
//-----------------------------------------------------------//
// Autor:Emerson B. Nascimento |Data: 15/10/2012             //
//-----------------------------------------------------------//
//Descricao: Funo que gera arquivo de txt relacionando as  //
//           vendas de um certo periodo e grupos de produtos//
//-----------------------------------------------------------//
//Nome:    relCurvABC(cDirNomArq,cGrupo)                     //
//-----------------------------------------------------------//
//Params | cDirNomArq->diretorio e nome do arquivo para grava//
//		 | o arquivo txt para envio por email                //
//       | cGrupo->Grupo para processa o relatrio           //
//-----------------------------------------------------------//
*/
Static Function relCurvABC(cDirNomArq,cGrupo)

#DEFINE CRLF CHR(13)+CHR(10) // FINAL DE LINHA
local nHandle := Fcreate(cDirNomArq,FC_NORMAL)
If nHandle == -1
	conout("O arquivo de nome no pode ser executado!	Verifique os parmetros.","Ateno!")
	Return
Endif

//variaveis do select
dInicial  := SubStr(DtoS(DATE()),1,6)+"01"
dFinal   := DtoS(DATE())
if(Empty(cGrupo))
	cGrupoIn:= "0105"     // Pega o Grupo de produtos para ser enviados.
	cGrupoFinal := "0105"
else
	cGrupoIn:= cGrupo
	cGrupoFinal:= cGrupo
endif

//Selecionar vendas totalizar                            

BeginSQL Alias "Vendas"
	%noparser%
	SELECT SUM(D2_QUANT) QUANT , SUM(D2_TOTAL) as VALOR, A1_NOME AS FARMACIA
    FROM %Table:SD2% AS SD2
			INNER JOIN %Table:SA1% AS SA1 ON SD2.D2_CLIENTE = SA1.A1_COD AND SD2.D2_LOJA = SA1.A1_LOJA
			INNER JOIN %Table:SF4% AS SF4 ON SD2.D2_TES = SF4.F4_CODIGO
    	  WHERE SA1.A1_GRPVEN = %exp:'000008'%
    	    AND SD2.D2_EMISSAO BETWEEN %exp:dInicial% AND %exp:dFinal%
    	  	AND SD2.D2_GRUPO >= %exp:cGrupoIn% AND SD2.D2_GRUPO <= %exp:cGrupoFinal%
    	  	AND (SD2.D2_TIPO = %exp:'N'% OR SD2.D2_TIPO = %exp:'C'%)
    	  	AND SF4.F4_DUPLIC = %exp:'S'%
    	  	AND SD2.%notdel%
    	   	AND SF4.%notdel%
    	  	AND SD2.D2_FILIAL = %xFilial:SD2% 
    	  	AND SF4.F4_FILIAL = %xFilial:SF4%
            GROUP BY SA1.A1_NOME
            ORDER BY QUANT DESC, SA1.A1_NOME
		  
EndSQL    



cTitulo:= "Arquivo Curva ABC Grupo "+IF(!Empty(cGrupo),cGrupoIn+" - "+cGrupoFinal,"Geral")
cTitulo+= " Periodo: "+DtoC(StoD(dInicial))+" - "+DtoC(StoD(dFinal))+CRLF
//escreve titulo
	fWrite(nHandle,cTitulo,Len(cTitulo)) 

cHead:=" "+Space(15)+ "FARMACIA"+Space(28)+"QUANTIDADE"+Space(7)+"VALOR"+Space(63)


	fWrite(nHandle,cHead,Len(cHead)) 
	
nTotGeral:=0
nTotDesGer:= 0	    
nPos:= 1

//criar array com as Vendas  


//     
aVendas:={}
DbSelectArea('Vendas')
While !Eof()
  aadd(aVendas,{Vendas->QUANT,Vendas->VALOR,Vendas->FARMACIA})		
  dbSkip()
Enddo	


aVendas := aSort(aVendas,,,{|x,y| x[3] > y[3]})

for i:=1 to len(aVendas)
    cLin:= Space(5)+PADR(aVendas[i][3],35," ")   // farmacia
    cLin+= PADL(AllTrim(Str(aVendas[i][1])),12," ")        // quant
    cLin+= PADL(Transform(aVendas[i][2],"@ze 9,999,999,999,999.99"),20," ")   //valor
    cLin+= Space(2)+PADL(Alltrim(Str(nPos++)),3, " ")+CRLF
	
	nTotGeral+= Vendas->QUANT
	nTotDesGer+= Vendas->VALOR
    fwrite(nHandle,cLin,Len(cLin))
 next

	
fclose(nHandle)	
Vendas->(DbCloseArea())


return


fclose(nHandle)	

Return

                                                                                     